open

Function open 

pub fn open() -> Option<Port>
Available on crate feature cgb only.
Open the port, if this machine has one.

A Game Boy Advance runs Color cartridges and has no infrared port, so is_cgb on its own is not enough to go on.